@@ -14,6 +14,7 @@ use URI ();
 use Socket6 (); # to ensure dependency is met
 use HTML::Entities (); # to ensure dependency is met
 use URI::QueryParam (); # part of URI, to add helper methods
+use MIME::Base64 'encode_base64';
 use Path::Class 'dir';
 use Module::Load ();
 use Data::Visitor::Tiny;
@@ -296,6 +297,9 @@ hook 'before_template' => sub {
 hook 'before_template' => sub {
     my $tokens = shift;
 
+    # quick b64 encode
+    $tokens->{atob} = sub { encode_base64(shift, '') };
+
     # allow portable static content
     $tokens->{uri_base} = request->base->path
       if request->base->path ne '/';
@@ -322,6 +326,7 @@ hook 'before_template' => sub {
     };
 
     # access to logged in user's roles (modulo RBAC)
+    # role will be "admin" "port_control" "radius" or "ldap"
     $tokens->{user_has_role} = sub {
         my ($role, $device) = @_;
         return false unless $role;
@@ -333,12 +338,13 @@ hook 'before_template' => sub {
         my $user = logged_in_user or return false;
         return true unless $user->portctl_role;
 
+        # this has the merged yaml and database config
         my $acl = setting('portctl_by_role')->{$user->portctl_role};
         if ($acl and (ref $acl eq q{} or ref $acl eq ref [])) {
             return true if acl_matches($device, $acl);
         }
         elsif ($acl and ref $acl eq ref {}) {
-            foreach my $key (grep { defined } sort keys %$acl) {
+            foreach my $key (grep { defined } keys %$acl) {
                 # lhs matches device, rhs matches port
                 # but we are not interested in the ports
                 return true if acl_matches($device, $key);
@@ -365,6 +371,9 @@ hook 'before_template' => sub {
         elsif ($mode =~ m/^report$/) {
             $tokens->{$sidebar_key} = uri_for("/$mode/$report");
         }
+        elsif ($mode =~ m/^admintask$/) {
+            $tokens->{$sidebar_key} = uri_for("/$mode/$report");
+        }
 
         foreach my $col (keys %{ var('sidebar_defaults')->{$sidebar_key} }) {
             $tokens->{$sidebar_key}->query_param($col,
